==> als-dynamic-router-0.1.0.tgz: package/router.js <==
let {join} = require('path')
let {readdirSync,lstatSync} = require('fs')
module.exports = class {
   constructor(app,routsPath) {
      this.routes = []
      this.mwRoutes = []
      this.getFilesList(routsPath)
      this.addRoutes(app)
   }
  
   getFilesList(dir,filelist = [],root,files) {
      if(root == undefined) root = dir
      if(!lstatSync(dir).isDirectory()) files = [dir]
      else files = readdirSync(dir)
      files.forEach(file => {
         let path = join(dir,file)
         if(lstatSync(path).isDirectory()) filelist = this.getFilesList(path,filelist,root)
         else {
            if(path.match(/(get|post|put|patch|delete)\.js$/)) {
               let { route,privat } = this.getRoute(path,root)
               if(!route.includes('.')) {
                  let parts = route.split('/')
                  route = route.split('/').map((part,i) => i==parts.length-1 ? '.'+part : part).join('/')
               }
               let array = route.split('.')
               route = array[0]
               let method = array[1]
               this.routes.push({privat,route,path,method})
            } else if(file.match(/^\#?mw\.js$/)) {
               let { route,privat } = this.getRoute(path,root,file)
               this.mwRoutes.push({privat,route,path})
            }
            else if(file.match(/^\#?router\.js$/)) 
               this.addRouter(path,root)
         }
      });
      return filelist
   }

   getRoute(path,root,file,route) {
      if(file) route = path.replace(file,'')
      route = path.replace(root,'').replace(/\\/g,'/').replace('.js','').replace(/\$/g,':').replace(/\#/g,'')
      route = route.replace(/mw|router$/,'')
      return {
         privat:path.match(/\#/)? true : false,
         route
      }
   }

   addRouter(path,root) {
      let {route,privat} = this.getRoute(path,root)
      let routes = require(path)
      Object.keys(routes).forEach(url => {
         let {method,path} = routes[url]
         url = (route+url).replace(/\/\//g,'/')
         this.routes.push({privat,route:url,path,method})
      });
   }

   addRoutes(app) {
      this.routes = this.routes.sort((a,b) => b.url > a.url ? 1 : -1)
      this.routes.forEach(obj => {
         let {privat,route,path,method} = obj
         let mw = this.mwRoutes.find(mwObj => {
            if(route.startsWith(mwObj.route)) {
               if(mwObj.privat && route.replace(mwObj.route,'').split('/').length <= 1) return mwObj
               else if(!mwObj.privat) return mwObj
            }
         })
         let array = [(req,res,next) => {
            req.routes = this.routes
            req.private = privat; 
            return next()
         }]
         if(mw !== undefined) array = this.mwToArray(mw.path,array)
         array = this.mwToArray(path,array)
         app[method](route,array)
      });
   }

   mwToArray(path,array,fn) {
      if(path !== undefined) {
         if(typeof path == 'string') fn = require(path)
         else fn = path
         if(!Array.isArray(fn)) array.push(fn)
         else array = [...array,...fn]
      }
      return array
   }

   static mw(array) {
      return function mw(req,res,next) {
         for(let i=array.length-1; i >= 0; i--) {
            let nextInArray = array[i+1]
            if(nextInArray == undefined) nextInArray = next
            let fn = array[i]
            array[i] = () => fn(req,res,nextInArray)
         }
         return array[0](req,res)
      }
   }

   static statics(staticsFn,notFound) {
      if(!notFound) notFound = (req,res) => res.status(404).end('Not found')
      return [staticsFn,function(req,res) {
         let {url,statics} = req
         if(statics) {
            let {join} = require('path')
            let {existsSync} = require('fs')
            let staticKeys = Object.keys(statics)
            staticKeys = staticKeys.sort((a,b) => b > a ? 1 : -1)
            let filePath = false
            for(let i=0; i<staticKeys.length; i++) {
               let route = staticKeys[i]
               let path = statics[route]
               if(url.startsWith(route)) {
                  let isFilePath = join(path,url.replace(route,''))
                  if(existsSync(isFilePath)) {
                     filePath = isFilePath
                     break
                  }
               }
            }
            if(filePath) return res.sendFile(filePath)
            else return notFound(req,res)
         }
      }]
   }

   static error(fn,errorFn) {
      return (req,res,next) => {
         try {
            return fn(req,res,next)
         } catch (error) {
            if(errorFn) return errorFn(req,res,error)
            else {
               console.log(error)
               return res.status(500).end('Internal server error')
            }
         }
      }
   }
}

==> als-dynamic-router-0.3.0.tgz: package/router.js <==
let {join} = require('path')
let {readdirSync,lstatSync,existsSync} = require('fs')
module.exports = class {
   constructor(app,routsPath) {
      this.routes = []
      this.mwRoutes = []
      this.getFilesList(routsPath)
      this.addRoutes(app)
   }
  
   getFilesList(dir,filelist = [],root,files) {
      if(root == undefined) root = dir
      if(!lstatSync(dir).isDirectory()) files = [dir]
      else files = readdirSync(dir)
      files.forEach(file => {
         let path = join(dir,file)
         if(lstatSync(path).isDirectory()) filelist = this.getFilesList(path,filelist,root)
         else {
            if(path.match(/(get|post|put|patch|delete)\.js$/)) {
               let { route,privat } = this.getRoute(path,root)
               if(!route.includes('.')) {
                  let parts = route.split('/')
                  route = route.split('/').map((part,i) => i==parts.length-1 ? '.'+part : part).join('/')
               }
               let array = route.split('.')
               route = array[0]
               let method = array[1]
               this.routes.push({privat,route,path,method})
            } else if(file.match(/^\#?mw\.js$/)) {
               let { route,privat } = this.getRoute(path,root,file)
               this.mwRoutes.push({privat,route,path})
            }
            else if(file.match(/^\#?router\.js$/)) 
               this.addRouter(path,root)
         }
      });
      return filelist
   }

   getRoute(path,root,file,route) {
      let privat
      if(file) {
         route = path.replace(file,'')
         privat = file.match(/\#/)? true : false
      } else privat = path.match(/\#/)? true : false
      route = path.replace(root,'').replace(/\\/g,'/').replace('.js','').replace(/\$/g,':').replace(/\#/g,'')
      route = route.replace(/mw|router$/,'')
      return {privat,route}
   }

   addRouter(path,root) {
      let {route,privat} = this.getRoute(path,root)
      let routes = require(path)
      Object.keys(routes).forEach(url => {
         let {method,path} = routes[url]
         url = (route+url).replace(/\/\//g,'/')
         this.routes.push({privat,route:url,path,method})
      });
   }

   addRoutes(app) {
      this.routes = this.routes.sort((a,b) => b.url > a.url ? 1 : -1)
      this.routes.forEach(obj => {
         let {privat,route,path,method} = obj
         let mw = this.mwRoutes.filter(mwObj => {
            if(route.startsWith(mwObj.route)) {
               if(mwObj.privat && route.replace(mwObj.route,'').split('/').length <= 1) return mwObj
               else if(!mwObj.privat) return mwObj
            }
         })
         let array = [(req,res,next) => {
            req.routes = this.routes
            req.private = privat; 
            return next()
         }]
         mw = mw.sort((a,b) => b.path > a.path ? 1 : -1)
         mw.forEach(obj => this.mwToArray(obj.path,array))

         array = this.mwToArray(path,array)
         app[method](route,array)
      });
   }
 
   mwToArray(path,array,fn) {
      if(path !== undefined) {
         if(typeof path == 'string') fn = require(path)
         else fn = path
         if(!Array.isArray(fn)) array.push(fn)
         else array = [...array,...fn]
      }
      return array
   }

   static mw(array) {
      return function mw(req,res,next) {
         for(let i=array.length-1; i >= 0; i--) {
            let nextInArray = array[i+1]
            if(nextInArray == undefined) nextInArray = next
            let fn = array[i]
            array[i] = () => fn(req,res,nextInArray)
         }
         return array[0](req,res)
      }
   }

   static statics(staticsFn,notFound) {
      const mime = require('mime-types')
      let root = join(__dirname,'..','..')
      if(!notFound) notFound = (req,res) => res.status(404).end('Not found')
      return [staticsFn,function(req,res) {
         let {url,statics} = req
         url = url.split('?')[0]
         if(statics) {
            let staticKeys = Object.keys(statics)
            staticKeys = staticKeys.sort((a,b) => b > a ? 1 : -1)
            let filePath = false
            for(let i=0; i<staticKeys.length; i++) {
               let route = staticKeys[i]
               let path = statics[route]
               path = join(root,...path.split('/'))
               if(url.startsWith(route)) {
                  let isFilePath = join(path,url.replace(route,''))
                  if(existsSync(isFilePath)) {
                     filePath = isFilePath
                     break
                  }
               }
            }
            if(filePath) {
               let type = mime.lookup(filePath)
               res.setHeader('content-type', type);
               return res.sendFile(filePath)
            } else return notFound(req,res)
         }
      }]
   }

   static isError(fn,errorFn) {
      return (req,res,next) => {
         try {
            return fn(req,res,next)
         } catch (error) {
            if(errorFn) return errorFn(req,res,error)
            else {
               console.log(error)
               return res.status(500).end('Internal server error')
            }
         }
      }
   }
}
